ete2.treeview._show_newick.Ui_Newick

Package ete2 :: Package treeview :: Module _show_newick :: Class Ui_Newick |
[hide private]
[frames] | no frames]

# Class Ui_Newick

source code

    object --+
             |
            Ui_Newick

Instance Methods | [hide private]
setupUi(self, Newick) | source code
retranslateUi(self, Newick) | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__init__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties | [hide private]
Inherited from `object`: `__class__`